# -*- coding: utf-8 -*-
#
# Copyright (C) 2020 CERN.
#
# Docker-Services-CLI is free software; you can redistribute it and/or modify
# it under the terms of the MIT License; see LICENSE file for more details.

"""CLI module."""

from distutils.sysconfig import get_python_lib
from functools import update_wrapper

import click

from .config import SERVICE_TYPES
from .env import (
    normalize_service_name,
    override_default_env,
    print_setup_env_config,
    set_env,
)
from .services import services_down, services_up


def env_output(env_set_command):
    """Decorate command to print exportable environment settings."""
    if env_set_command not in ["export", "unset"]:
        click.secho("Wrong environment set command.", fg="red")
        exit(1)

    def print_env_output(func):
        @click.option(
            "--env",
            is_flag=True,
            default=False,
            help="Print export statements to set environment.",
        )
        def _print_env_output(*args, **kwargs):
            env = kwargs.pop("env", False)
            services = kwargs.get("services") or SERVICE_TYPES
            if env:
                # comment command output until env export
                click.echo(": '")
            click.get_current_context().invoke(func, *args, **kwargs)
            if env:
                # end of multiline comment, start of export statements
                click.echo("'")
                print_setup_env_config(
                    services,
                    click.get_current_context().info_name,
                    env_set_command=env_set_command,
                )

        return update_wrapper(_print_env_output, func)

    return print_env_output


def services_by_type(func):
    """Decorate command adding all service types as options.

    :param func: The function that implements the Click command to which the
        service types options will be added.

    :return: A wrapped function around the passed Click command which exposes
        all ``config.SERVICES_TYPES`` as Click options. The list of services
        by type is injected as ``services`` keyword argument.
    """

    def collect_services_by_type(*args, **kwargs):
        services = {}
        for service_type in SERVICE_TYPES:
            service = kwargs.pop(service_type)
            if service:
                services.setdefault(service_type, []).extend(
                    service if isinstance(service, list) else [service]
                )

        kwargs["services"] = services
        click.get_current_context().invoke(func, *args, **kwargs)

    def validate_service_name(ctx, service_type, services_list):
        available_services = SERVICE_TYPES.get(service_type.name, [])
        for service in services_list:
            if not (
                normalize_service_name(service)
                or normalize_service_name(service) in available_services
            ):
                raise click.BadParameter(
                    "{service} is not a valid service of type {type}. "
                    "Try one of: \n{available_services}".format(
                        service=service,
                        type=service_type.name,
                        available_services=available_services,
                    )
                )
        return list(services_list)

    for service_type in SERVICE_TYPES:
        click.option(
            "--{}".format(service_type),
            callback=validate_service_name,
            multiple=True,
            help="Specify which service should run as {0}. "
            "Available {0} services: {1}.".format(
                service_type, ", ".join(SERVICE_TYPES.get(service_type))
            ),
        )(func)

    return update_wrapper(collect_services_by_type, func)


class ServicesCtx(object):
    """Context class for docker services cli."""

    def __init__(self, filepath, verbose):
        """Constructor."""
        self.filepath = filepath
        self.verbose = verbose


@click.group()
@click.version_option()
@click.option(
    "--filepath",
    "-f",
    required=False,
    default=f"{get_python_lib()}/docker_services_cli/docker-services.yml",
    type=click.Path(exists=True),
    help="Path to a docker compose file with the desired services definition.",
)
@click.option(
    "--verbose",
    is_flag=True,
    default=False,
    help="Verbose output.",
)
@click.pass_context
def cli(ctx, filepath, verbose):
    """Initialize CLI context."""
    set_env()
    ctx.obj = ServicesCtx(filepath=filepath, verbose=verbose)


@cli.command()
@click.option(
    "--no-wait",
    is_flag=True,
    help="Wait for services to be up (use healthchecks).",
)
@click.option(
    "--retries",
    default=6,
    type=int,
    help="Number of times to retry a service's healthcheck.",
)
@services_by_type
@env_output(env_set_command="export")
@click.pass_obj
def up(services_ctx, services, no_wait, retries):
    r"""Boots up the required services.

    Example: \n
    \t $ docker-services-cli up --db postgresql11

    Note: All services will be boot up if no service is specified.
    """
    _services = [s for services_list in services.values() for s in services_list]

    # NOTE: docker-compose boots up all if none is provided
    if len(_services) == 1 and _services[0].lower() == "all":
        _services = []

    override_default_env(services_to_override=_services)
    click.secho("Environment setup", fg="green")

    normalized_services = [normalize_service_name(s) for s in _services]
    services_up(
        services=normalized_services,
        filepath=services_ctx.filepath,
        wait=(not no_wait),
        retries=retries,
        verbose=services_ctx.verbose,
    )
    click.secho("Services up!", fg="green")


@cli.command()
@env_output(env_set_command="unset")
@click.pass_obj
def down(services_ctx):
    """Boots down the required services."""
    services_down(filepath=services_ctx.filepath)
    click.secho("Services down!", fg="green")



# -*- coding: utf-8 -*-
#
# Copyright (C) 2020 CERN.
#
# Docker-Services-CLI is free software; you can redistribute it and/or modify
# it under the terms of the MIT License; see LICENSE file for more details.

"""Environment module."""

import logging
import os
import sys
from distutils.version import StrictVersion

import click

from .config import SERVICE_TYPES, SERVICES, SERVICES_ALL_DEFAULT_VERSIONS


def normalize_service_name(service_with_version):
    """Return the name of the passed service without version number."""
    service_name = None
    if service_with_version in SERVICES:
        service_name = service_with_version
    else:
        for name in SERVICES:
            if name in service_with_version:
                service_name = name
                break

    return service_name


def _set_default_env(services_version, default_version):
    """Set environmental variable value if it does not exist."""
    os.environ[services_version] = os.environ.get(services_version, default_version)


def _is_version(version):
    """Checks if a string is a version of the format `x.y.z`.

    NOTE: It is not mandatory to be up to patch level. The following would be
    accepted:
    - 10.1
    - 9
    - 15.0.1a2
    """
    try:
        # StrictVersion fails on plain numbers (e.g. "10")
        if version.isnumeric():
            return True
        StrictVersion(version)
        return True
    except Exception:
        return False


def _load_or_set_env(services_version, default_version):
    """Set a specific service version from the environment.

    It parses the value to distinguish between a version and a defined latest.
    NOTE: It requires that all variables for latest versions have been set up.
    """
    version_from_env = os.environ.get(services_version, default_version)
    # e.g. the ES_7_LATEST string from env, need a second get.
    major_version_from_env = os.environ.get(version_from_env)

    if not version_from_env:
        os.environ[services_version] = default_version

    elif _is_version(version_from_env):
        os.environ[services_version] = version_from_env

    elif major_version_from_env and _is_version(major_version_from_env):
        os.environ[services_version] = major_version_from_env

    else:
        click.secho(
            f"Environment variable for version {version_from_env} not set \
            or set to a non-compliant format (dot separated numbers).",
            fg="red",
        )
        sys.exit(1)


def override_default_env(services_to_override=None):
    """Override default environment according to list of services with version.

    :param services_to_override: List of service name strings including
        service version without any separator e.g. ``postgresql11``.
    """
    services_to_override = set(services_to_override or []).difference(SERVICES.keys())
    if services_to_override:
        num_services_to_override = len(services_to_override)
        for service_name in SERVICES:
            for service_override in services_to_override:
                if service_name in service_override:
                    service_override_version = service_override.replace(
                        service_name, ""
                    )
                    env_var_with_version = (
                        f"{service_name.upper()}_" f"{service_override_version}_LATEST"
                    )
                    if SERVICES_ALL_DEFAULT_VERSIONS.get(env_var_with_version):
                        os.environ[
                            f"{service_name.upper()}_VERSION"
                        ] = SERVICES_ALL_DEFAULT_VERSIONS.get(env_var_with_version)
                    else:
                        available_major_versions = [
                            v.split(".")[0]
                            for v in SERVICES[service_name]["DEFAULT_VERSIONS"].values()
                        ]
                        click.secho(
                            f"No major version {service_override_version} "
                            f"for {service_name}. "
                            "Please use one of the available "
                            f"ones: {available_major_versions}",
                            fg="red",
                        )
                        exit(1)
                    num_services_to_override -= 1
                    if not num_services_to_override:
                        return


def set_env():
    """Export the environment variables for services and versions."""
    for key, value in SERVICES_ALL_DEFAULT_VERSIONS.items():
        _set_default_env(key, value)

    for service in SERVICES.values():
        for key, value in service.items():
            if key.endswith("_VERSION"):
                _load_or_set_env(key, value)
            elif key == "CONTAINER_CONFIG_ENVIRONMENT_VARIABLES":
                for envvar_name, envvar_value in value.items():
                    _set_default_env(envvar_name, envvar_value)


def print_setup_env_config(services, called_from, env_set_command="export"):
    """Prints setup environment instructions."""
    should_print_instructions = False
    for service_type, services_list in services.items():
        if called_from == "up" and len(services_list) > 1:
            logging.warning(
                "Multiple %s services %s are being configured. "
                "Note that only %s will be accessible.",
                service_type,
                services_list,
                services_list[-1],
            )

        for key, value in get_service_env_vars(service_type, services_list):
            command = f"{env_set_command} {key}"
            if env_set_command == "export":
                command += f"={value}"
            click.echo(command)
            should_print_instructions = True

    if should_print_instructions:
        click.secho("# Configure your environment running:", fg="yellow")
        instructions = f'# eval "$(docker-services-cli {called_from}'
        if called_from == "up" and services != SERVICE_TYPES:
            instructions += " " + " ".join(
                [
                    "--{0} {1}".format(service_type, service)
                    for service_type, services_list in services.items()
                    for service in services_list
                ]
            )
        instructions += ' --env)"'
        click.secho(instructions, fg="yellow")


def get_service_env_vars(service_type, services_list):
    """Get all or a subset of service environment variables."""
    envvars = []
    for service in services_list:
        service_envvars_by_type = (
            SERVICES.get(normalize_service_name(service))
            .get("CONTAINER_CONNECTION_ENVIRONMENT_VARIABLES", {})
            .get(service_type, {})
            .items()
        )
        for key, value in service_envvars_by_type:
            envvars.append((key, value))

    return envvars



# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2022 CERN.
#
# Docker-Services-CLI is free software; you can redistribute it and/or modify
# it under the terms of the MIT License; see LICENSE file for more details.

"""Module to ease the creation and management of services.

The specific version for the services can be set through environment variables

.. code-block:: console

    $ export ES_VERSION=7.2.0

It can also use the centrally managed (supported) major version:

.. code-block:: console

    $ export ES_VERSION=ES_7_LATEST

Then it simply needs to boot up the services. Note that if no version was
exported in the environment, the CLI will use the default values set in
``env.py``.

.. code-block:: console

    $ docker-services-cli up es postgresql redis

And turn them of once they are not needed anymore:

.. code-block:: console

    $ docker-services-cli down
"""

__version__ = "0.4.2"

__all__ = ("__version__",)



# -*- coding: utf-8 -*-
#
# Copyright (C) 2020 CERN.
#
# Docker-Services-CLI is free software; you can redistribute it and/or
# modify it under the terms of the MIT License; see LICENSE file for more
# details.

"""Module tests."""

import os

import pytest

from docker_services_cli.config import SERVICES
from docker_services_cli.env import (
    _is_version,
    _load_or_set_env,
    override_default_env,
    set_env,
)


def test_is_version():
    assert _is_version("10")
    assert _is_version("10.1")
    assert _is_version("10.1.2")
    assert _is_version("10.1.2a3")
    assert not _is_version("SERVICE_10_LATEST")


def test_load_or_set_env_default():
    """Tests the loading of a given default value."""
    _load_or_set_env("TEST_VERSION_DEFAULT", "1.0.0")

    assert os.environ.get("TEST_VERSION_DEFAULT") == "1.0.0"

    del os.environ["TEST_VERSION_DEFAULT"]


def test_load_or_set_env_from_value():
    """Tests the loading of a set value."""
    os.environ["TEST_VERSION_DEFAULT"] = "2.0.0"
    _load_or_set_env("TEST_VERSION_DEFAULT", "1.0.0")

    assert os.environ.get("TEST_VERSION_DEFAULT") == "2.0.0"

    del os.environ["TEST_VERSION_DEFAULT"]


def test_load_or_set_env_from_string():
    """Tests the loading of a service default value from string."""
    os.environ["TEST_SERVICE_VERSION_DEFAULT"] = "1.0.0"
    os.environ["TEST_VERSION_DEFAULT"] = "TEST_SERVICE_VERSION_DEFAULT"
    _load_or_set_env("TEST_VERSION_DEFAULT", "2.0.0")

    assert os.environ.get("TEST_VERSION_DEFAULT") == "1.0.0"

    del os.environ["TEST_SERVICE_VERSION_DEFAULT"]
    del os.environ["TEST_VERSION_DEFAULT"]


def test_setversion_not_set():
    """Tests the loading when it results in a system exit."""
    os.environ["TEST_VERSION_DEFAULT"] = "TEST_NOT_EXISTING"

    with pytest.raises(SystemExit) as ex:
        _load_or_set_env("TEST_VERSION_DEFAULT", "2.0.0")

    assert ex.value.code == 1

    del os.environ["TEST_VERSION_DEFAULT"]


@pytest.mark.parametrize(
    "service_and_version_string,envvar,expected_value",
    [
        # case in which no version is passed, default value should be used
        (
            "elasticsearch",
            "ELASTICSEARCH_VERSION",
            SERVICES["elasticsearch"]["DEFAULT_VERSIONS"][
                SERVICES["elasticsearch"]["ELASTICSEARCH_VERSION"]
            ],
        ),
        # case in which a wrong version is passed, fails
        pytest.param(
            "postgresql-1",
            "POSTGRESQL_VERSION",
            SERVICES["postgresql"]["DEFAULT_VERSIONS"][
                SERVICES["postgresql"]["POSTGRESQL_VERSION"]
            ],
            marks=pytest.mark.xfail,
        ),
        # case in which a correct non default version is passed
        (
            "mysql8",
            "MYSQL_VERSION",
            SERVICES["mysql"]["DEFAULT_VERSIONS"]["MYSQL_8_LATEST"],
        ),
    ],
)
def test_override_default_service_versions(
    service_and_version_string, envvar, expected_value
):
    """Test overriding default versions with service+version strings."""
    set_env()  # set default environment
    override_default_env([service_and_version_string])
    assert os.getenv(envvar) == expected_value



# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2022 CERN.
#
# Docker-Services-CLI is free software; you can redistribute it and/or modify
# it under the terms of the MIT License; see LICENSE file for more details.

"""Configuration module.

Configuration values (e.g. service configuration) need to be set through
environment variables. However, sane defaults are provided below.

The list of services to be configured is taken from ``SERVICES``. Each one
should contain a ``<SERVICE_NAME>_VERSION`` varaible.

Service's version are treated slightly different:

- If the variable is not found in the environment, it will use the set default.
- If the variable is set with a version number (e.g. 10, 10.7) it will use
  said value.
- If the variable is set with a string point to one of the configured
  ``latests`` it will load the value of said ``latest`` and use it.

This means that the environment set/load logic will first set the default
versions before loading a given service's version.
"""

DOCKER_SERVICES_FILEPATH = "docker_services_cli/docker-services.yml"
"""Docker services file default path."""

# Elasticsearch
ELASTICSEARCH = {
    "ELASTICSEARCH_VERSION": "ELASTICSEARCH_7_LATEST",
    "DEFAULT_VERSIONS": {
        "ELASTICSEARCH_6_LATEST": "6.8.12",
        "ELASTICSEARCH_7_LATEST": "7.9.0",
    },
}
"""Elasticsearch service configuration."""

# PostrgreSQL
POSTGRESQL = {
    "POSTGRESQL_VERSION": "POSTGRESQL_12_LATEST",
    "DEFAULT_VERSIONS": {
        "POSTGRESQL_9_LATEST": "9.6.24",  # deprecated, reached end of life
        "POSTGRESQL_10_LATEST": "10.20",
        "POSTGRESQL_11_LATEST": "11.15",
        "POSTGRESQL_12_LATEST": "12.10",
        "POSTGRESQL_13_LATEST": "13.6",
        "POSTGRESQL_14_LATEST": "14.2",
    },
    "CONTAINER_CONFIG_ENVIRONMENT_VARIABLES": {
        "POSTGRESQL_USER": "invenio",
        "POSTGRESQL_PASSWORD": "invenio",
        "POSTGRESQL_DB": "invenio",
    },
    "CONTAINER_CONNECTION_ENVIRONMENT_VARIABLES": {
        "db": {
            "SQLALCHEMY_DATABASE_URI": "postgresql+psycopg2://invenio:invenio@localhost:5432/invenio"
        }
    },
}
"""Postgresql service configuration."""

# MySQL
MYSQL = {
    "MYSQL_VERSION": "MYSQL_5_LATEST",
    "DEFAULT_VERSIONS": {"MYSQL_5_LATEST": "5.7.31", "MYSQL_8_LATEST": "8.0.21"},
    "CONTAINER_CONFIG_ENVIRONMENT_VARIABLES": {
        "MYSQL_USER": "invenio",
        "MYSQL_PASSWORD": "invenio",
        "MYSQL_DB": "invenio",
        "MYSQL_ROOT_PASSWORD": "invenio",
    },
    "CONTAINER_CONNECTION_ENVIRONMENT_VARIABLES": {
        "db": {
            "SQLALCHEMY_DATABASE_URI": "mysql+pymysql://invenio:invenio@localhost:3306/invenio"
        }
    },
}
"""MySQL service configuration."""

REDIS = {
    "REDIS_VERSION": "REDIS_7_LATEST",
    "DEFAULT_VERSIONS": {"REDIS_6_LATEST": "6", "REDIS_7_LATEST": "7"},
    "CONTAINER_CONNECTION_ENVIRONMENT_VARIABLES": {
        "mq": {"BROKER_URL": "redis://localhost:6379/0"},
        "cache": {"CACHE_TYPE": "redis"},
    },
}
"""Redis service configuration."""

RABBITMQ = {
    "RABBITMQ_VERSION": "RABBITMQ_3_LATEST",
    "DEFAULT_VERSIONS": {"RABBITMQ_3_LATEST": "3"},
    "CONTAINER_CONNECTION_ENVIRONMENT_VARIABLES": {
        "mq": {"BROKER_URL": "amqp://localhost:5672//"}
    },
}
"""RabbitMQ service configuration."""

SERVICES = {
    "elasticsearch": ELASTICSEARCH,
    "postgresql": POSTGRESQL,
    "mysql": MYSQL,
    "redis": REDIS,
    "rabbitmq": RABBITMQ,
}
"""List of services to configure."""

SERVICES_ALL_DEFAULT_VERSIONS = {
    **ELASTICSEARCH.get("DEFAULT_VERSIONS", {}),
    **POSTGRESQL.get("DEFAULT_VERSIONS", {}),
    **REDIS.get("DEFAULT_VERSIONS", {}),
    **MYSQL.get("DEFAULT_VERSIONS", {}),
    **RABBITMQ.get("DEFAULT_VERSIONS", {}),
}
"""Services default latest versions."""

SERVICE_TYPES = {
    "search": ["elasticsearch"],
    "db": ["mysql", "postgresql"],
    "cache": [
        "redis",
    ],
    "mq": ["rabbitmq", "redis"],
}
"""Types of offered services."""



# -*- coding: utf-8 -*-
#
# Copyright (C) 2020 CERN.
#
# Docker-Services-CLI is free software; you can redistribute it and/or modify
# it under the terms of the MIT License; see LICENSE file for more details.

"""Services module."""

import time
from os import path
from subprocess import PIPE, Popen, check_call

import click

from .config import DOCKER_SERVICES_FILEPATH, MYSQL, POSTGRESQL, SERVICE_TYPES


def _run_healthcheck_command(command, verbose=False):
    """Runs a given command, returns True if it succeeds, False otherwise."""
    p = Popen(command, stdout=PIPE, stderr=PIPE)
    output, error = p.communicate()
    output = output.decode("utf-8")
    error = error.decode("utf-8")
    if p.returncode == 0:
        if verbose:
            click.secho(output, fg="green")
        return True
    if p.returncode != 0:
        if verbose:
            click.secho(
                f"Healthcheck failed.\nOutput: {output}\nError:{error}", fg="red"
            )
        return False


def es_healthcheck(*args, **kwargs):
    """Elasticsearch healthcheck."""
    verbose = kwargs["verbose"]

    return _run_healthcheck_command(
        ["curl", "-f", "localhost:9200/_cluster/health?wait_for_status=green"], verbose
    )


def postgresql_healthcheck(*args, **kwargs):
    """Postgresql healthcheck."""
    filepath = kwargs["filepath"]
    verbose = kwargs["verbose"]

    return _run_healthcheck_command(
        [
            "docker-compose",
            "--file",
            filepath,
            "exec",
            "-T",
            "postgresql",
            "bash",
            "-c",
            "pg_isready",
        ],
        verbose,
    )


def mysql_healthcheck(*args, **kwargs):
    """Mysql healthcheck."""
    filepath = kwargs["filepath"]
    verbose = kwargs["verbose"]
    password = MYSQL["CONTAINER_CONFIG_ENVIRONMENT_VARIABLES"]["MYSQL_ROOT_PASSWORD"]

    return _run_healthcheck_command(
        [
            "docker-compose",
            "--file",
            filepath,
            "exec",
            "-T",
            "mysql",
            "bash",
            "-c",
            f'mysql -p{password} -e "select Version();"',
        ],
        verbose,
    )


def rabbitmq_healthcheck(*args, **kwargs):
    """Rabbitmq healthcheck."""
    filepath = kwargs["filepath"]
    verbose = kwargs["verbose"]

    return _run_healthcheck_command(
        [
            "docker-compose",
            "--file",
            filepath,
            "exec",
            "-T",
            "rabbitmq",
            "bash",
            "-c",
            "rabbitmq-diagnostics check_running",
        ],
        verbose,
    )


def redis_healthcheck(*args, **kwargs):
    """Redis healthcheck."""
    filepath = kwargs["filepath"]
    verbose = kwargs["verbose"]

    return _run_healthcheck_command(
        [
            "docker-compose",
            "--file",
            filepath,
            "exec",
            "-T",
            "redis",
            "bash",
            "-c",
            "redis-cli ping",
            "|",
            "grep 'PONG'",
            "&>/dev/null;",
        ],
        verbose,
    )


HEALTHCHECKS = {
    "elasticsearch": es_healthcheck,
    "postgresql": postgresql_healthcheck,
    "mysql": mysql_healthcheck,
    "rabbitmq": rabbitmq_healthcheck,
    "redis": redis_healthcheck,
}
"""Health check functions module path, as string."""


def wait_for_services(
    services, filepath=DOCKER_SERVICES_FILEPATH, max_retries=6, verbose=False
):
    """Wait for services to be up.

    It performs configured healthchecks in a serial fashion, following the
    order given in the ``up`` command. If the services is an empty list, to be
    compliant with `docker-compose` it will perform the healthchecks of all the
    services.
    """
    if len(services) == 0:
        services = HEALTHCHECKS.keys()

    for service in services:
        exp_backoff_time = 2
        try_ = 1
        # Using plain __import__ to avoid depending on invenio-base
        check = HEALTHCHECKS[service]
        ready = check(filepath=filepath, verbose=verbose)
        while not ready and try_ < max_retries:
            click.secho(
                f"{service} not ready at {try_} retries, waiting "
                f"{exp_backoff_time}s",
                fg="yellow",
            )
            try_ += 1
            time.sleep(exp_backoff_time)
            exp_backoff_time *= 2
            ready = check(filepath=filepath, verbose=verbose)

        if not ready:
            click.secho(f"Unable to boot up {service}", fg="red")
            exit(1)
        else:
            click.secho(f"{service} up and running!", fg="green")


def services_up(
    services, filepath=DOCKER_SERVICES_FILEPATH, wait=True, retries=6, verbose=False
):
    """Start the given services up.

    docker-compose is smart about not rebuilding an image if
    there is no need to, so --build is not a slow default. In addition
    ``--detach`` is not supported in 1.17.0 or previous.
    """
    services = services or [
        service for _, services in SERVICE_TYPES.items() for service in services
    ]
    if not path.exists(filepath):
        click.secho(
            f"Filepaht {filepath} for docker-services.yml file does" "not exist.",
            fg="red",
        )
        exit(1)

    command = ["docker-compose", "--file", filepath, "up", "-d"]
    command.extend(services)

    check_call(command)
    if wait:
        wait_for_services(services, filepath, max_retries=retries, verbose=verbose)


def services_down(filepath=DOCKER_SERVICES_FILEPATH):
    """Stops the given services.

    It does not requries the services. It stops containers and removes
    containers, networks, volumes, and images created by ``up``.
    """
    command = ["docker-compose", "--file", filepath, "down", "--volumes"]

    check_call(command)



# -*- coding: utf-8 -*-
#
# Copyright (C) 2020 CERN.
#
# Docker-Services-CLI is free software; you can redistribute it and/or modify it
# under the terms of the MIT License; see LICENSE file for more details.

"""Python module to ease the creation and management of external services."""

from setuptools import setup

setup()
